@@ -14,7 +14,8 @@ from PyQt6.QtWidgets import (
     QLabel, QListView, QCompleter, QComboBox, QSizePolicy,
     QApplication, QHBoxLayout, QVBoxLayout, QCheckBox, QWidget,
     QPushButton, QMessageBox, QAbstractItemView, QLineEdit,
-    QTextEdit, QTableWidget, QTableWidgetItem, QHeaderView
+    QTextEdit, QTableWidget, QTableWidgetItem, QHeaderView,
+    QHBoxLayout, QVBoxLayout, QGridLayout, QFormLayout
     )
 import os,re,subprocess,sys,re,traceback,pydot, enum, inspect, sys, traceback, threading,json,traceback,logging,requests
 from abstract_utilities import is_number,make_list,safe_read_from_json,read_from_file,make_dirs
